@@ -9,101 +9,7 @@ from urllib.parse import SplitResult, parse_qsl
 from ..record import Record
 
 
-BACKENDS = {}
-
-
-class ABCDabaseBackend(abc.ABC):
-
-    name: t.ClassVar[str]
-    record_cls = Record
-
-    def __init__(self, url: SplitResult, **options):
-        self.url = url
-        self.options = dict(parse_qsl(url.query), **options)
-
-    def __init_subclass__(cls, *args, **kwargs):
-        """Register a backend."""
-        super().__init_subclass__(*args, **kwargs)
-        BACKENDS[cls.name] = cls
-
-    @abc.abstractmethod
-    async def connect(self) -> None:
-        raise NotImplementedError
-
-    @abc.abstractmethod
-    async def disconnect(self) -> None:
-        raise NotImplementedError
-
-    @abc.abstractmethod
-    def connection(self) -> ABCConnection:
-        raise NotImplementedError
-
-    @abc.abstractmethod
-    async def acquire(self) -> t.Any:
-        raise NotImplementedError
-
-    @abc.abstractmethod
-    async def release(self, conn: t.Any) -> None:
-        raise NotImplementedError
-
-
-class ABCConnection(abc.ABC):
-
-    def __init__(self, database: ABCDabaseBackend):
-        self.database = database
-        self.transactions: t.List[ABCTransaction] = []
-        self._conn = None
-        self._lock = asyncio.Lock()
-
-    @property
-    def conn(self):
-        assert self.is_ready, "Connection is not acquired"
-        return self._conn
-
-    @property
-    def is_ready(self) -> bool:
-        return self._conn is not None
-
-    async def acquire(self) -> ABCConnection:
-        if self._conn is None:
-            async with self._lock:
-                self._conn = await self.database.acquire()
-
-        return self
-
-    __aenter__ = acquire
-
-    async def release(self, *args) -> ABCConnection:
-        async with self._lock:
-            conn, self._conn = self._conn, None
-            if conn:
-                await self.database.release(conn)
-            return self
-
-    __aexit__ = release
-
-    @abc.abstractmethod
-    async def execute(self, query: str, *args, **params) -> t.Any:
-        raise NotImplementedError
-
-    @abc.abstractmethod
-    async def executemany(self, query: str, *args, **params) -> t.Any:
-        raise NotImplementedError
-
-    @abc.abstractmethod
-    async def fetchall(self, query: str, *args, **params) -> t.List[t.Mapping]:
-        raise NotImplementedError
-
-    @abc.abstractmethod
-    async def fetchone(self, query: str, *args, **params) -> t.Optional[t.Mapping]:
-        raise NotImplementedError
-
-    @abc.abstractmethod
-    async def fetchval(self, query: str, *args, column: t.Any = 0, **params) -> t.Any:
-        raise NotImplementedError
-
-    def transaction(self) -> ABCTransaction:
-        raise NotImplementedError
+BACKENDS = []
 
 
 class ABCTransaction(abc.ABC):
@@ -160,14 +66,129 @@ class ABCTransaction(abc.ABC):
             self.is_finished = True
 
 
-from .sqlite import *  # noqa
+class ABCConnection(abc.ABC):
+
+    transaction_cls: t.ClassVar[t.Type[ABCTransaction]]
+
+    def __init__(self, database: ABCDatabaseBackend):
+        self.database = database
+        self.transactions: t.List[ABCTransaction] = []
+        self._conn = None
+        self._lock = asyncio.Lock()
+
+    @property
+    def conn(self):
+        assert self.is_ready, "Connection is not acquired"
+        return self._conn
+
+    @property
+    def is_ready(self) -> bool:
+        return self._conn is not None
+
+    async def acquire(self) -> ABCConnection:
+        if self._conn is None:
+            async with self._lock:
+                self._conn = await self.database.acquire()
+
+        return self
+
+    __aenter__ = acquire
+
+    async def release(self, *args) -> ABCConnection:
+        async with self._lock:
+            conn, self._conn = self._conn, None
+            if conn:
+                await self.database.release(conn)
+            return self
+
+    __aexit__ = release
+
+    @abc.abstractmethod
+    async def execute(self, query: str, *args, **params) -> t.Any:
+        raise NotImplementedError
+
+    @abc.abstractmethod
+    async def executemany(self, query: str, *args, **params) -> t.Any:
+        raise NotImplementedError
+
+    @abc.abstractmethod
+    async def fetchall(self, query: str, *args, **params) -> t.List[t.Mapping]:
+        raise NotImplementedError
+
+    @abc.abstractmethod
+    async def fetchone(self, query: str, *args, **params) -> t.Optional[t.Mapping]:
+        raise NotImplementedError
+
+    @abc.abstractmethod
+    async def fetchval(self, query: str, *args, column: t.Any = 0, **params) -> t.Any:
+        raise NotImplementedError
+
+    def transaction(self) -> ABCTransaction:
+        return self.transaction_cls(self)
+
+
+class ABCDatabaseBackend(abc.ABC):
+
+    name: t.ClassVar[str]
+    db_type: t.ClassVar[str]
+
+    record_cls = Record
+    connection_cls: t.ClassVar[t.Type[ABCConnection]]
+
+    def __init__(self, url: SplitResult, **options):
+        self.url = url
+        self.options = dict(parse_qsl(url.query), **options)
+
+    def __init_subclass__(cls, *args, **kwargs):
+        """Register a backend."""
+        BACKENDS.append(cls)
+        return super().__init_subclass__(*args, **kwargs)
+
+    def __str__(self):
+        return self.db_type
+
+    def __repr__(self):
+        return f"<Backend {self}>"
+
+    @abc.abstractmethod
+    async def connect(self) -> None:
+        raise NotImplementedError
+
+    @abc.abstractmethod
+    async def disconnect(self) -> None:
+        raise NotImplementedError
+
+    @abc.abstractmethod
+    async def acquire(self) -> t.Any:
+        raise NotImplementedError
+
+    @abc.abstractmethod
+    async def release(self, conn: t.Any) -> None:
+        raise NotImplementedError
+
+    def connection(self) -> ABCConnection:
+        return self.connection_cls(self)
+
+
+#  Import available backends
+#  -------------------------
 
 try:
-    from .postgres import *  # noqa
+    from ._aiosqlite import Backend as AIOSQLiteBackend  # noqa
 except ImportError:
     pass
 
 try:
-    from .mysql import *  # noqa
+    from ._asyncpg import Backend as AsyncPGBackend  # noqa
+except ImportError:
+    pass
+
+try:
+    from ._aiopg import Backend as AIOPGBackend  # noqa
+except ImportError:
+    pass
+
+try:
+    from ._aiomysql import Backend as AIOMySQLBackend  # noqa
 except ImportError:
     pass
